@@ -69,8 +69,6 @@ class PushButtonPlus(PushButton):
         self._icon = icon
         self.native.setIconSize(self.native.size())
 
-    icon_path = icon
-
     @property
     def font_size(self):
         """Font size of the button."""
@@ -137,7 +135,7 @@ class ToolButtonPlus(PushButtonPlus):
     def set_menu(self, qmenu: QMenu):
         """Set menu-like behavior to the tool button."""
         self.native.setMenu(qmenu)
-        self.native.setPopupMode(QToolButton.InstantPopup)
+        self.native.setPopupMode(QToolButton.ToolButtonPopupMode.InstantPopup)
         self.native.setIcon(qmenu.icon())  # icon have to be copied.
 
     def set_shortcut(self, key):
@@ -157,42 +155,52 @@ class mguiLike:
 
     @property
     def parent(self):
+        """Return the parent object."""
         return self.native.parent()
 
     @parent.setter
     def parent(self, obj: mguiLike | Widget):
+        """Set the parent object."""
         self.native.setParent(obj.native)
 
     @property
     def name(self) -> str:
+        """Name of the object."""
         return self.native.objectName()
 
     @name.setter
     def name(self, value: str):
+        """Set the name of the object."""
         self.native.setObjectName(value)
 
     @property
     def tooltip(self) -> str:
+        """Tooltip of the object."""
         return self.native.toolTip()
 
     @tooltip.setter
     def tooltip(self, value: str):
+        """Set the tooltip of the object."""
         self.native.setToolTip(value)
 
     @property
     def enabled(self) -> bool:
+        """True if the object is enabled."""
         return self.native.isEnabled()
 
     @enabled.setter
     def enabled(self, value: bool):
+        """Set the enabled state of the object."""
         self.native.setEnabled(value)
 
     @property
     def visible(self) -> bool:
+        """Visibility of the object."""
         return self.native.isVisible()
 
     @visible.setter
     def visible(self, value: bool):
+        """Set the visibility of the object."""
         self.native.setVisible(value)
 
     @property
@@ -208,12 +216,17 @@ class AbstractAction(mguiLike):
 
     changed = Signal(object)
     support_value: bool
-    native: QAction | QWidgetAction
+    _native: QAction | QWidgetAction
 
     @property
     def value(self):
         raise NotImplementedError()
 
+    @property
+    def native(self) -> QAction | QWidgetAction:
+        """The native Qt object."""
+        return self._native
+
     def from_options(self, options):
         raise NotImplementedError()
 
@@ -224,7 +237,7 @@ class Action(AbstractAction):
     def __init__(
         self, *args, name: str = None, text: str = None, gui_only: bool = True, **kwargs
     ):
-        self.native = QAction(*args, **kwargs)
+        self._native = QAction(*args, **kwargs)
         self.mgui: FunctionGuiPlus = None
         self._doc = ""
         self._unwrapped = False
@@ -244,6 +257,7 @@ class Action(AbstractAction):
 
     def set_shortcut(self, key):
         self.native.setShortcut(key)
+        return None
 
     def reset_choices(self, *_: Any):
         """Reset child Categorical widgets."""
@@ -276,8 +290,6 @@ class Action(AbstractAction):
         icon.install(self)
         self._icon = icon
 
-    icon_path = icon
-
     def from_options(self, options: dict[str] | Callable):
         if callable(options):
             try:
@@ -302,7 +314,7 @@ class WidgetAction(AbstractAction, Generic[_W]):
                 f"The first argument must be a magicgui-like widget, got {type(widget)}"
             )
 
-        self.native = QWidgetAction(parent)
+        self._native = QWidgetAction(parent)
         self.widget = widget
         name = widget.name
         self.native.setObjectName(name)
@@ -353,6 +365,16 @@ class WidgetAction(AbstractAction, Generic[_W]):
         if hasattr(self.widget, "text"):
             self.widget.text = value
 
+    @property
+    def tooltip(self) -> str:
+        """Tooltip of the inner widget."""
+        return self.widget.tooltip
+
+    @tooltip.setter
+    def tooltip(self, value: str):
+        """Set the tooltip of the inner widget."""
+        self.widget.tooltip = value
+
     def _labeled_widget(self):
         return self.widget._labeled_widget()
 
