@@ -1,4 +1,5 @@
 from __future__ import annotations
+import sys
 from typing import (
     TYPE_CHECKING,
     Generic,
@@ -35,6 +36,12 @@ if TYPE_CHECKING:
     from superqt import QLabeledRangeSlider
 
 
+if sys.platform == "win32":
+    _FONT = "Consolas"
+else:
+    _FONT = "Menlo"
+
+
 @merge_super_sigs
 class OptionalWidget(Container):
     """
@@ -138,7 +145,7 @@ class ConsoleTextEdit(TextEdit):
         from qtpy.QtGui import QFont, QTextOption
 
         self.native: QTextEdit
-        font = QFont("Consolas")
+        font = QFont(_FONT)
         font.setStyleHint(QFont.Monospace)
         font.setFixedPitch(True)
         self.native.setFont(font)
