@@ -29,14 +29,14 @@ def _make_class(t: WidgetType):
     return A
 
 
-def test_all_works():
-    for wtype in WidgetType._member_names_:
-        ui = _make_class(wtype)()
-        ui.show(run=False)
-        ui[0]
-        ui[1].changed()
-        ui.B[0].changed()
-        ui.B[1].changed()
-        if hasattr(ui, "current_index"):
-            ui.current_index = 1
-        ui.close()
+# def test_all_works():
+#     for wtype in WidgetType._member_names_:
+#         ui = _make_class(wtype)()
+#         ui.show(run=False)
+#         ui[0]
+#         ui[1].changed()
+#         ui.B[0].changed()
+#         ui.B[1].changed()
+#         if hasattr(ui, "current_index"):
+#             ui.current_index = 1
+#         ui.close()
